**unreleased**
**0.2.3**
* implements responsive sidebar
**0.2.2**
* fix main container layout
**0.2.1**
* fix assets folder path
**0.2.0**
* implements new base layout
* adds example application
* implements generate-assets command
**0.1.1**
* implements initial package version